MapUtils class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

mapAsync<T, S>({required T data, required Mapper<T, S> mapper, bool printError = kDebugMode}) Future<S>
Maps the value of the future to a new value.
mapAsyncInIsolate<T, S>({required T data, required Mapper<T, S> mapper, bool useWorkManager = true, bool printError = kDebugMode}) Future<S>
Maps the value of the future to a new value in an isolate. If useWorkManager is set to true, it will use workerManager to execute the task. Otherwise, it will use compute to execute the task.