PlayxLoggerSettings class

Settings for initializing a logger without depending on any implementation.

Constructors

PlayxLoggerSettings({bool enabled = kDebugMode, bool useColors = true, bool printToConsole = kDebugMode, bool printLoggerName = true, bool printDateTime = false, LogLevel level = LogLevel.verbose, String lineSymbol = '─', int maxLineWidth = 140, LoggerFormatter formatter = const ExtendedLoggerFormatter(), LoggerOutput? output, LoggerFilter? filter})

Properties

colors Map<LogLevel, AnsiPen>
Field to setup custom log colors
final
enabled bool
Field for enable and disable print logger
final
filter → LoggerFilter?
final
formatter → LoggerFormatter
You can setup different formatter ExtendedLoggerFormatter, ColoredLoggerFormatter Or your own fully customized formatter with extends LoggerFormatter
final
hashCode int
The hash code for this object.
no setterinherited
level → LogLevel
Current log level All messages with a priority below this will be ignored
final
lineSymbol String
The symbol separating logs by lower border
final
maxLineWidth int
Maximum width of the lower border
final
output → LoggerOutput?
Field to setup custom log colors
final
printDateTime bool
Whether to print the date and time in the log
final
printLoggerName bool
When name is not null, it will be used as a prefix for all logs
final
printToConsole bool
Field for enable and disable print logger to console
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useColors bool
Field for enable and disable colored logs
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited