setString static method

Future<void> setString(
  1. String key,
  2. String value
)

Sets the value associated with the given key as a String.

  • key: The key under which the value will be stored.
  • value: The String value to store.

Implementation

static Future<void> setString(
  String key,
  String value,
) =>
    securePrefs.write(key: key, value: value);