PlayxSecurePrefsSettings class

Settings for PlayxSecurePrefsSettings .

Constructors

PlayxSecurePrefsSettings({IOSOptions iosOptions = const IOSOptions(accessibility: KeychainAccessibility.first_unlock), AndroidOptions androidOptions = const AndroidOptions(encryptedSharedPreferences: true), LinuxOptions linuxOptions = LinuxOptions.defaultOptions, WindowsOptions windowsOptions = WindowsOptions.defaultOptions, WebOptions webOptions = WebOptions.defaultOptions, MacOsOptions macOsOptions = MacOsOptions.defaultOptions, bool clearOnReinstall = true, bool createSecurePrefs = true})
const

Properties

androidOptions AndroidOptions
final
clearOnReinstall bool
If clearOnReinstall is set to true, the storage is cleared on app reinstall.
final
createSecurePrefs bool
If createSecurePrefs is set to true, the storage will be created on boot.
final
hashCode int
The hash code for this object.
no setterinherited
iosOptions IOSOptions
final
linuxOptions LinuxOptions
final
macOsOptions MacOsOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webOptions WebOptions
final
windowsOptions WindowsOptions
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited