PlayxThemeScaleAnimation class

Defines a scale animation effect with adjustable scale values.

Inheritance

Constructors

PlayxThemeScaleAnimation({double begin = .5, double end = 1.0, bool isReversed = false, VoidCallback? onAnimationFinish, Duration duration = const Duration(milliseconds: 300)})
Creates a PlayxThemeScaleAnimation with specified scale values.
const

Properties

begin double
The starting scale value for the scale animation.
final
duration Duration
The duration of the animation. Defaults to 300 milliseconds. This controls how long the animation takes to complete.
finalinherited
end double
The ending scale value for the scale animation.
final
hashCode int
The hash code for this object.
no setterinherited
isReversed bool
Determines if the animation should be played in reverse. If set to true, the animation will run in the reverse direction.
finalinherited
onAnimationFinish VoidCallback?
A callback function that is triggered when the animation finishes. You can use this to perform additional actions after the animation completes.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animate({required AnimationController controller}) Future<void>
Animates the selected PlayxThemeAnimation using the provided controller.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited