AndroidBiometricType enum
Controls which authentication methods are accepted when biometric authentication is used.
Values
- strongBiometricOnly → const AndroidBiometricType
-
Only Class 3 (strong) biometrics are accepted — e.g. fingerprint or hardware-backed face recognition. Device credentials (PIN, pattern, password) are explicitly rejected.
- biometricOrDeviceCredential → const AndroidBiometricType
-
Strong biometrics or device credentials (PIN, pattern, password) are accepted. This is the default.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AndroidBiometricType> - A constant List of the values in this enum, in order of their declaration.