setString static method
Sets the value associated with the given key as a String.
key: The key under which the value will be stored.value: TheStringvalue to store.
Implementation
static Future<void> setString(
String key,
String value,
) =>
securePrefs.write(key: key, value: value);