PlayxThemeSwitcher class
A StatelessWidget that allows for building widgets based on the current XTheme.
This widget uses a ThemeSwitcherBuilder to build its child widget with the current theme provided by PlayxTheme. It provides context and theme information for changing the theme, especially useful for animations like PlayxThemeClipperAnimation. allowing you to use the widget’s offset and context for precise animation control.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- PlayxThemeSwitcher
Constructors
- PlayxThemeSwitcher({Key? key, required ThemeSwitcherBuilder builder})
-
const
Properties
- builder → ThemeSwitcherBuilder
-
Creates a PlayxThemeSwitcher that provides context and theme information
for changing the theme, especially useful for animations like PlayxThemeClipperAnimation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited